<?php

namespace Drupal\entity_update\Form;

use Drupal\entity_update\EntityUpdate;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class CheckEntityUpdate.
 *
 * @package Drupal\entity_update\Form
 *
 * @ingroup entity_update
 */
class EntityUpdateExec extends FormBase {

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId() {
    return 'entity_update_exec';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $link_help = '/admin/help/entity_update';
    $form['messages']['about'] = [
      '#type' => 'markup',
      '#markup' => "This page allow to update entities. Please refer to the <a href='$link_help'>Help page</a>.",
      '#prefix' => '<div>',
      '#suffix' => '</div>',
    ];

    $form['actions']['submit_basic'] = [
      '#type' => 'submit',
      '#value' => $this->t('Basic Update'),
      '#submit' => ['::submitFormBasic'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * Run updates using basic method.
   */
  public function submitFormBasic(array &$form, FormStateInterface $form_state) {
    $list = EntityUpdate::getEntityTypesToUpdate();
    if (empty($list)) {
      drupal_set_message($this->t("Nothing to update."));
      return;
    }

    try {
      entity_update_exec_basic_update();
      drupal_set_message($this->t("Entity update success"));
    }
    catch (\Exception $e) {
      drupal_set_message($this->t("Entity update Fail"), 'error');
      drupal_set_message($e->getMessage(), 'error');
    }
  }

}
